[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - interminebio.iterators.BedIterator
  - interminebio.iterators.FastaIterator
  - interminebio.iterators.GFF3Iterator
  - interminebio.SequenceDataQuery
    - interminebio.RegionQuery: This module allows you to construct queries that retrieve data about sequences and sequence features in biologically relevant formats, where those features are located overlapping genomic intervals.
    - interminebio.SequenceQuery: This module allows you to construct queries that retrieve data about sequences and sequence features in biologically relevant formats.